@@ -1,4 +1,5 @@
-#imports essential functions from the vandal module.
+#imports essential functions from the unin module.
+import vandal
 from vandal.eoq import eoq
 from vandal.hub import hub
 from vandal.misc.global_functions import *
@@ -22,4 +23,4 @@ def Replace(directory, find, replace, filePattern):
             with open(filepath, "w") as f:
                 f.write(s)
 
-Replace('vandal', 'vandal', 'unin', '*.py')
\ No newline at end of file
+Replace('unin', 'vandal', 'unin', '*.py')
\ No newline at end of file
